Documentation
¶
Index ¶
- func Error(ctx context.Context, args ...interface{})
- func Errorf(ctx context.Context, format string, args ...interface{})
- func ErrorfDepth(ctx context.Context, depth int, format string, args ...interface{})
- func Fatal(ctx context.Context, args ...interface{})
- func Fatalf(ctx context.Context, format string, args ...interface{})
- func FatalfDepth(ctx context.Context, depth int, format string, args ...interface{})
- func Flush()
- func Info(ctx context.Context, args ...interface{})
- func Infof(ctx context.Context, format string, args ...interface{})
- func InfofDepth(ctx context.Context, depth int, format string, args ...interface{})
- func SetLogger(l Logger)
- func V(level int32) bool
- func Warning(ctx context.Context, args ...interface{})
- func Warningf(ctx context.Context, format string, args ...interface{})
- func WarningfDepth(ctx context.Context, depth int, format string, args ...interface{})
- func WithLogTag(ctx context.Context, name string, value interface{}) context.Context
- type Logger
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ErrorfDepth ¶
ErrorfDepth log
func FatalfDepth ¶
FatalfDepth log
func InfofDepth ¶
InfofDepth log
func SetLogger ¶
func SetLogger(l Logger)
SetLogger is used to override the kronos logger. It should be called before initializing kronos
func WarningfDepth ¶
WarningfDepth log
Types ¶
type Logger ¶
type Logger interface {
// Info log
Info(ctx context.Context, args ...interface{})
// Infof log
Infof(ctx context.Context, format string, args ...interface{})
// InfofDepth log
InfofDepth(ctx context.Context, depth int, format string, args ...interface{})
// Warning log
Warning(ctx context.Context, args ...interface{})
// Warningf log
Warningf(ctx context.Context, format string, args ...interface{})
// WarningfDepth log
WarningfDepth(ctx context.Context, depth int, format string, args ...interface{})
// Error log
Error(ctx context.Context, args ...interface{})
// Errorf log
Errorf(ctx context.Context, format string, args ...interface{})
// ErrorfDepth log
ErrorfDepth(ctx context.Context, depth int, format string, args ...interface{})
// Fatal log
Fatal(ctx context.Context, args ...interface{})
// Fatalf log
Fatalf(ctx context.Context, format string, args ...interface{})
// FatalfDepth log
FatalfDepth(ctx context.Context, depth int, format string, args ...interface{})
// V returns whether the given verbosity should be logged
V(level int32) bool
// WithLogTag returns a context with a log tag
WithLogTag(ctx context.Context, name string, value interface{}) context.Context
// Flush the logger
Flush()
}
Logger can be be used to override the logger used by kronos
Click to show internal directories.
Click to hide internal directories.